@@ -42,7 +42,7 @@ from .site import (
     RequestRevisions, MultiRequestRevisions,
 )
 from .file import TrackedFile, Revision, DefaultFileMap
-from .kitsu import KitsuAPIWrapper, KitsuBindings
+from .kitsu import KitsuAPIWrapper, KitsuBindings, KitsuUsers
 from .dependency import DependencyTemplates
 
 
@@ -90,21 +90,12 @@ class LoginPageWidget(CustomPageWidget):
         logged_in = self.session.cmds.Flow.call(
             self.project_oid,
             "log_in",
-            args={},
-            kwargs={"kitsu_login": kitsu_login, "kitsu_password": kitsu_password},
+            args=[kitsu_login, kitsu_password],
+            kwargs={},
         )
 
-        if logged_in:
-            if logged_in == 1:
-                text = "<font color=#C71B1F>Login failed... Check credentials !</font>"
-            elif logged_in == 2:
-                support = self.session.cmds.Flow.get_value(self.project_oid + "/admin/project_settings/support")
-                text = "<font color=#D66700>A user with the same name but a different Kitsu ID is already registered for this project."
-                if support:
-                    text += f"<br>We invite you to contact the support of the project ({support}).</font>"
-                else:
-                    text += "</font>"
-            
+        if not logged_in:
+            text = "<font color=#C71B1F>Login failed... Check credentials !</font>"
             self.error_label.setText(text)
             return
 
@@ -361,6 +352,11 @@ class KitsuConfig(flow.Object):
     )
     uploadable_files = flow.Param("")
     bindings = flow.Child(KitsuBindings)
+    users = flow.Child(KitsuUsers).ui(
+        expanded=True,
+        action_submenus=True,
+        items_action_submenus=True,
+    )
     gazu_api = flow.Child(KitsuAPIWrapper).ui(
         hidden=True
     )
@@ -609,6 +605,9 @@ class Project(flow.Object):
             return None
         
         return self.admin.users[name]
+    
+    def get_users(self):
+        return self.admin.users
 
     def get_current_site(self):
         """
@@ -687,48 +686,40 @@ class Project(flow.Object):
 
         return kitsu_api.host_is_valid()
 
-    def log_in(self, kitsu_login, kitsu_password):
-        kitsu_api = self.kitsu_api()
-
-        self.update_kitsu_host(self.admin.kitsu.server_url.get())
-        kitsu_user_data = kitsu_api.log_in(kitsu_login, kitsu_password)
-
-        if kitsu_user_data is None:
-            return 1
-        
-        kitsu_id = kitsu_user_data['user']['id']
-
-        # Set current user
-        # user_name = self.admin.users.get_user_name(kitsu_login)
-        user = self.admin.users.get_user_by_uid(kitsu_id)
+    def log_in(self, login, password):
+        # Check if the login matches a registered user
 
+        user = self.admin.users.get_user(login)
         if user is None:
-            # Create user profile if not registered
-            user = self.admin.users.add_user(kitsu_id, kitsu_login)
+            return False
+        
+        # Authenticate to Kitsu
 
-            if user is None:
-                return 2
+        kitsu = self.kitsu_api()
+        self.update_kitsu_host(self.admin.kitsu.server_url.get())
 
-            # user_name = user.name()
+        if not kitsu.log_in(user.name(), password):
+            # Invalid credentials
+            return False
         
         self.set_user_name(user.name())
 
-        # Create user folder at first login
+        # Save authentification tokens
+        
         user_settings_folder = self.user_settings_folder()
         if not os.path.exists(user_settings_folder):
             os.makedirs(user_settings_folder)
 
-        # Save authentification tokens
-        tokens = kitsu_api.get_tokens()
+        tokens = kitsu.get_tokens()
         kitsu_config = {}
-        kitsu_config["tokens"] = tokens
-        kitsu_config["kitsu_host"] = kitsu_api.get_host()
+        kitsu_config['tokens'] = tokens
+        kitsu_config['kitsu_host'] = kitsu.get_host()
 
         if user_settings_folder is not None:
-            with open("%s/kitsu_config.json" % user_settings_folder, "w+") as f:
+            with open('%s/kitsu_config.json' % user_settings_folder, 'w+') as f:
                 json.dump(kitsu_config, f)
 
-        return 0
+        return True
     
     def log_out(self):
         self.kitsu_api().log_out()
