@@ -8,6 +8,7 @@ from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 from kabaret.flow_entities.entities import Entity
 
 from ..utils.kabaret.flow_entities.entities import EntityView
+from ..utils.flow.file_processing import ProcessSequenceFiles
 
 from .departments import Department
 from .maputils import ItemMap, CreateItemAction, ClearMapAction, SimpleCreateAction
@@ -871,71 +872,6 @@ class RenderSequencePlayblasts_XX(flow.Action):
             shot.submit(self.pool.get())
 
 
-class ProcessSequenceFiles(flow.Action):
-
-    _sequence = flow.Parent()
-
-    def __init__(self, parent, name):
-        super(ProcessSequenceFiles, self).__init__(parent, name)
-        self._files_data = None
-        self._task_names = []
-    
-    def ensure_files_data(self):
-        '''
-        Method used to cache computed files data
-        '''
-        if self._files_data is None:
-            self._files_data = self._compute_files_data()
-        
-        return self._files_data
-    
-    def _compute_files_data(self):
-        '''
-        Computes data related to files contained in a sequence
-        '''
-        raise NotImplementedError(
-            'Subclasses must return shot files data'
-        )
-    
-    def get_shot_task_files(self, fnpatterns, tags=[]):
-        self._task_names.clear()
-        
-        template = self.root().project().admin.dependency_templates['shot']
-        default_dep_names = template.get_default_dependency_names()
-        dependencies = template.get_dependencies()
-        
-        template_tasks_files = []
-        
-        for dep_name in default_dep_names:
-            dep = dependencies[dep_name]
-            files = []
-            
-            for file_name, file_data in dep['files'].items():
-                file_tags = file_data.get('tags', [])
-                
-                if not file_tags and tags:
-                    continue
-                if not set(tags).issubset(set(file_tags)):
-                    continue
-                        
-                for pattern in fnpatterns:
-                    if fnmatch(file_name, pattern):
-                        files.append((file_name, file_data))
-            
-            if files:
-                template_tasks_files.append((
-                    dep_name,
-                    files
-                ))
-                self._task_names.append(dep_name)
-        
-        return template_tasks_files
-    
-    def get_shot_task_names(self):
-        self.ensure_files_data()
-        return self._task_names
-
-
 class RenderSequencePlayblasts(ProcessSequenceFiles):
     
     ICON = ('icons.gui', 'film-strip-with-two-photograms')
@@ -1024,7 +960,7 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
         return files_data
     
     def _fill_ui(self, ui):
-        ui['custom_page'] = 'libreflow.utils.ui.RenderSequencePlayblastsWidget'
+        ui['custom_page'] = 'libreflow.utils.ui.file_processing.RenderSequencePlayblastsWidget'
 
 
 class UploadSequencePlayblastsToKitsu(ProcessSequenceFiles):
@@ -1133,7 +1069,7 @@ class UploadSequencePlayblastsToKitsu(ProcessSequenceFiles):
         return files_data
     
     def _fill_ui(self, ui):
-        ui['custom_page'] = 'libreflow.utils.ui.UploadSequencePlayblastsWidget'
+        ui['custom_page'] = 'libreflow.utils.ui.file_processing.UploadSequencePlayblastsWidget'
 
 
 class Sequence(KitsuSequence):
