@@ -15,6 +15,7 @@ class KitsuAPIWrapper(flow.Object):
 
     _server_url = flow.Param("")
     _config = flow.Parent()
+    _user_login_per_mapped_name = flow.HashParam()
 
     def set_host(self, url):
         gazu.client.set_host(url)
@@ -28,16 +29,22 @@ class KitsuAPIWrapper(flow.Object):
     def get_server_url(self):
         return self._server_url.get()
 
-    def log_in(self, username, password):
-        try:
-            user_data = gazu.log_in(username, password)
-        except (
-            gazu.exception.AuthFailedException,
-            gazu.exception.ServerErrorException,
-        ):
-            user_data = None
+    def log_in(self, user_name, password):
+        login = self.get_user_login(user_name)
+        success = False
 
-        return user_data
+        if login is not None:
+            try:
+                gazu.log_in(login, password)
+            except (
+                gazu.exception.AuthFailedException,
+                gazu.exception.ServerErrorException,
+            ):
+                pass
+            else:
+                success = True
+
+        return success
     
     def log_out(self):
         gazu.log_out()
@@ -58,6 +65,18 @@ class KitsuAPIWrapper(flow.Object):
                 type(exc) == gazu.exception.ParameterException
                 or type(exc) == gazu.exception.ServerErrorException
             )
+    
+    def get_user_login(self, user_mapped_name):
+        kitsu_login = None
+        if self._user_login_per_mapped_name.has_key(user_mapped_name):
+            kitsu_login = self._user_login_per_mapped_name.get_key(user_mapped_name)
+        
+        return kitsu_login
+    
+    def set_user_login(self, user_mapped_name, kitsu_login):
+        self._user_login_per_mapped_name.set_key(
+            user_mapped_name, kitsu_login
+        )
 
     def current_user_logged_in(self):
         """
@@ -451,6 +470,59 @@ class KitsuBindings(flow.Object):
             return None
 
 
+class ChangeKitsuUserLogin(flow.Action):
+
+    login = flow.SessionParam('')
+
+    _user = flow.Parent()
+    _map  = flow.Parent(2)
+
+    def needs_dialog(self):
+        self.login.set(self._user.get_login())
+        return True
+    
+    def get_buttons(self):
+        return ['Save', 'Cancel']
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        self._user.set_login(self.login.get())
+        self._map.touch()
+
+
+class KitsuUser(flow.SessionObject):
+    
+    edit = flow.Child(ChangeKitsuUserLogin)
+
+    def get_login(self):
+        return self.root().project().kitsu_api().get_user_login(self.name())
+    
+    def set_login(self, login):
+        self.root().project().kitsu_api().set_user_login(self.name(), login)
+
+
+class KitsuUsers(flow.DynamicMap):
+
+    @classmethod
+    def mapped_type(cls):
+        return KitsuUser
+
+    def mapped_names(self, page_num=0, page_size=None):
+        return self.root().project().get_users().mapped_names()
+    
+    def columns(self):
+        return ['Name', 'Login']
+    
+    def _fill_row_cells(self, row, item):
+        row['Name'] = item.name()
+        row['Login'] = item.get_login()
+    
+    def _fill_row_style(self, style, item, row):
+        style['activate_oid'] = item.edit.oid()
+
+
 class KitsuTaskStatus(PresetChoiceValue):
     
     DEFAULT_EDITOR = 'choice'
