@@ -63,7 +63,7 @@ class Asset(KitsuAsset):
     settings = flow.Child(ContextualView).ui(hidden=True)
     description = flow.Param("")
 
-    departments = flow.Child(AssetDepartments).ui(expanded=True)
+    tasks = flow.Child(AssetDepartments).ui(expanded=True)
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
