@@ -389,15 +389,23 @@ class UserStatus(flow.values.ChoiceValue):
     CHOICES = ["User", "Admin", "Supervisor"]
 
 
+class SessionUserStatus(flow.values.SessionValue):
+
+    DEFAULT_EDITOR = 'choice'
+
+    def choices(self):
+        return ["User", "Admin", "Supervisor"]
+
+
 class AddUserAction(flow.Action):
 
     ICON = ("icons.gui", "plus-sign-in-a-black-circle")
 
     _users = flow.Parent()
 
-    id = flow.Param("").ui(label="ID")
-    kitsu_login = flow.Param("").ui(label="Kitsu login")
-    status = flow.Param("User", UserStatus)
+    user_id = flow.SessionParam("").ui(label="ID")
+    login   = flow.SessionParam("")
+    status  = flow.SessionParam("User", SessionUserStatus)
 
     def get_buttons(self):
         return ["Add", "Cancel"]
@@ -406,10 +414,11 @@ class AddUserAction(flow.Action):
         if button == "Cancel":
             return
 
-        user = self._users.add(self.id.get())
-        user.kitsu_id.set(self.kitsu_login.get())
-        user.status.set(self.status.get())
-
+        user = self._users.add_user(
+            self.user_id.get(),
+            self.login.get(),
+            self.status.get()
+        )
         self._users.touch()
 
 
@@ -417,13 +426,18 @@ class User(flow.Object):
 
     ICON = ("icons.gui", "user")
 
-    kitsu_id = flow.Param("").ui(label="Kitsu login", editable=False)
-    kitsu_uid = flow.Param("").ui(label="Kitsu ID", editable=False)
+    login  = flow.Param().watched()
     status = flow.Param("User", UserStatus).ui(editable=False)
 
     bookmarks = flow.Child(UserBookmarks)
     preferences = flow.Child(UserPreferences)
 
+    _map = flow.Parent()
+
+    def child_value_changed(self, child_value):
+        if child_value is self.login:
+            self._map.set_user_login(self.name(), self.login.get())
+
 
 class Users(flow.Map):
 
@@ -437,58 +451,45 @@ class Users(flow.Map):
     add_user_action = flow.Child(AddUserAction).ui(label="Add user")
 
     _name_by_uid = flow.HashParam()
+    _mapped_name_per_login = flow.HashParam() # Allow to retrieve users by their logins
 
     @classmethod
     def mapped_type(cls):
         return flow.injection.injectable(User)
 
     def columns(self):
-        return ['ID', 'Kitsu login']
+        return ['ID', 'Login']
 
     def is_admin(self, username):
         user = self.get_mapped(username)
         return user.status.get() == "Admin"
     
-    def add_user(self, kitsu_id, kitsu_login, status="User"):
-        name = self.get_user_name(kitsu_login)
-
-        if name is None or self.has_mapped_name(name):
-            return None
-
+    def add_user(self, name, login, status='User'):
         user = self.add(name)
-        user.kitsu_id.set(kitsu_login)
-        user.kitsu_uid.set(kitsu_id)
         user.status.set(status)
-
-        self._name_by_uid.set_key(kitsu_id, name)
+        user.login.set(login)
+        self.set_user_login(name, login)
 
         return user
     
-    def get_user_name(self, kitsu_id):
-        def replace(s, substrings, rep):
-            res = s
-            for ss in substrings:
-                res = res.replace(ss, rep)
-            
-            return res
-
-        name = kitsu_id.split('@')[0]
-        name = replace(name, ['.', '-', '_'], '')
-        name = name.lower()
-        
-        return name
+    def remove_user(self, name):
+        self.remove(name)
+        self._mapped_name_per_login.del_key(name)
     
-    def get_user_by_uid(self, uid):
-        try:
-            return self.get_mapped(
-                self._name_by_uid.get_key(uid)
-            )
-        except KeyError:
+    def get_user(self, login):
+        if not self._mapped_name_per_login.has_key(login):
             return None
+        
+        name = self._mapped_name_per_login.get_key(login)
+        return self.get_mapped(name)
+    
+    def set_user_login(self, mapped_name, login):
+        u = self.get_mapped(mapped_name)
+        self._mapped_name_per_login.set_key(login, mapped_name)
 
     def _fill_row_cells(self, row, item):
         row["ID"] = item.name()
-        row["Kitsu login"] = item.kitsu_id.get()
+        row["Login"] = item.login.get()
     
     def _fill_row_style(self, style, item, row):
         style['icon'] = self.STYLE_BY_STATUS[item.status.get()]
